# Licensed to the EDAN LeadGen LLC under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The EDAN LeadGen LLC licenses
# this file to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

#
# Documentation
#
# http://www.smspins.com/pins/api.php
#
import requests
import json

API_ENDPOINT   = "http://www.smspins.com/pins/apiv2"

class SMSPinsAPIClient(object):
     def __init__(self,token,module):
          self.token     = token
          self.module    = module
     def _get(self, uri):
          r    = requests.get(uri)
          data = json.loads(r.text)
          return data
     def _request( self, method, **kwargs ):
          uri_parts = []
          uri_parts.append(API_ENDPOINT)
          uri_parts.append(self.token)
          uri_parts.append(self.module)
          uri_parts.append(method)
          for key in kwargs:
               uri_parts.append(str(kwargs[key]))
          uri  = '/'.join(uri_parts)
          return self._get(uri)

class BulkSMSClient(SMSPinsAPIClient):
     def __init__( self, token ):
          super(BulkSMSClient,self).__init__(token,'bulk_sms')

     def request(self,telephone_id):
          kwargs  = {'telephone_id':telephone_id}
          return self._request('request',**kwargs)
     def telephones(self):
          return self._request('telephones')
     def status(self, request_id):
          kwargs  = {'request_id':request_id}
          return self._request('status',**kwargs)
     def cancel(self, request_id):
          kwargs  = {'request_id':request_id}
          return self._request('cancel',**kwargs)
     def smses_by_tid(self,telephone_id):
          kwargs  = {'telephone_id':telephone_id}
          return self._request('smses_by_tid',**kwargs)
     def enable_autocheck(self,telephone_id):
          kwargs  = {'telephone_id':telephone_id,'enable': 'enable'}
          return self._request('autocheck',**kwargs)
     def disable_autocheck(self,telephone_id):
          kwargs  = {'telephone_id':telephone_id,'disable': 'disable'}
          return self._request('autocheck',**kwargs)

class NumberChangeClient(SMSPinsAPIClient):
     def __init__( self, token ):
          super(NumberChangeClient,self).__init__(token,'nc')
     def request(self,telephone_id,zip):
          kwargs  = {'telephone_id':telephone_id,'zip':zip}
          return self._request('request',**kwargs)
     def status(self, request_id):
          kwargs  = {'request_id':request_id}
          return self._request('status',**kwargs)
     def cancel(self, request_id):
          kwargs  = {'request_id':request_id}
          return self._request('cancel',**kwargs)
     def requests(self):
          return self._request('requests')

if '__main__' == __name__:
     API_KEY   = 'YOUR_API_KEY_HERE'
     bulksms    = BulkSMSClient(API_KEY)
     print bulksms.telephones()
     #print bulksms.request(1)
     #print bulksms.status(1)
     #print bulksms.cancel(1)
     #print bulksms.smses_by_tid(1)
     #print bulksms.enable_autocheck(1)
     #print bulksms.disable_autocheck(1)
     
     
     nc    = NumberChangeClient(API_KEY)
     #print nc.request(1,'11432')
     print nc.status(1)
     #print nc.cancel(33)
     #print nc.requests()